@@ -8,7 +8,6 @@ use Carp;
 use IO::Handle;
 use File::Basename qw(basename);
 
-use RPC::ExtDirect::Util ();
 use RPC::ExtDirect::Config;
 use RPC::ExtDirect::API;
 use RPC::ExtDirect;
@@ -25,7 +24,7 @@ die __PACKAGE__." requires RPC::ExtDirect 3.0+"
 # Version of this module.
 #
 
-our $VERSION = '3.21_001';
+our $VERSION = '3.01';
 
 ### PUBLIC CLASS METHOD (CONSTRUCTOR) ###
 #
@@ -350,11 +349,6 @@ sub _extract_post_data {
     # Here file uploads data is stored
     my @_uploads = ();
 
-    # This is to suppress a really annoying warning in CGI.pm 4.08+.
-    # I am perfectly aware of what the list context is and how to
-    # use it, thank you very much. :/
-    local $CGI::LIST_CONTEXT_WARN = 0;
-
     # Now if the form IS involved, it gets a little bit complicated
     PARAM:
     for my $param ( keys %keyword ) {
@@ -379,11 +373,6 @@ sub _extract_post_data {
         };
     };
 
-    # Metadata is JSON encoded; decode_metadata lives by side effects!
-    if ( exists $keyword{metadata} ) {
-        RPC::ExtDirect::Util::decode_metadata($self, \%keyword);
-    }
-
     # Remove extType because it's meaningless later on
     delete $keyword{ extType };
 
